from setuptools import setup

setup(name='diceset',
      version='0.1',
      description='A simple dice set creator and roller.',
      packages=['diceset'],
      author = 'Alexandru Gradinaru',
      author_email = 'gradinaru.alex@gmail.com',
      zip_safe=False)
